@@ -2,7 +2,6 @@
 
 from __future__ import annotations
 
-import sys
 from io import BytesIO
 from os.path import join
 
@@ -12,8 +11,6 @@ from mkdocs.config import load_config
 
 from mkdocstrings import Inventory, InventoryItem
 
-sphinx = pytest.importorskip("sphinx.util.inventory", reason="Sphinx is not installed")
-
 
 @pytest.mark.parametrize(
     "our_inv",
@@ -22,10 +19,13 @@ sphinx = pytest.importorskip("sphinx.util.inventory", reason="Sphinx is not inst
         Inventory([InventoryItem(name="object_path", domain="py", role="obj", uri="page_url")]),
         Inventory([InventoryItem(name="object_path", domain="py", role="obj", uri="page_url#object_path")]),
         Inventory([InventoryItem(name="object_path", domain="py", role="obj", uri="page_url#other_anchor")]),
+        Inventory([InventoryItem(name="o", domain="py", role="obj", uri="u#o", dispname="first line\nsecond line")]),
     ],
 )
 def test_sphinx_load_inventory_file(our_inv: Inventory) -> None:
     """Perform the 'live' inventory load test."""
+    sphinx = pytest.importorskip("sphinx.util.inventory", reason="Sphinx is not installed")
+
     buffer = BytesIO(our_inv.format_sphinx())
     sphinx_inv = sphinx.InventoryFile.load(buffer, "", join)
 
@@ -36,9 +36,10 @@ def test_sphinx_load_inventory_file(our_inv: Inventory) -> None:
         assert item.name in sphinx_inv[f"{item.domain}:{item.role}"]
 
 
-@pytest.mark.skipif(sys.version_info < (3, 7), reason="using plugins that require Python 3.7")
 def test_sphinx_load_mkdocstrings_inventory_file() -> None:
     """Perform the 'live' inventory load test on mkdocstrings own inventory."""
+    sphinx = pytest.importorskip("sphinx.util.inventory", reason="Sphinx is not installed")
+
     mkdocs_config = load_config()
     mkdocs_config["plugins"].run_event("startup", command="build", dirty=False)
     try:
@@ -55,3 +56,29 @@ def test_sphinx_load_mkdocstrings_inventory_file() -> None:
 
     for item in own_inv.values():
         assert item.name in sphinx_inv[f"{item.domain}:{item.role}"]
+
+
+@pytest.mark.parametrize(
+    "our_inv",
+    [
+        Inventory(),
+        Inventory([InventoryItem(name="object_path", domain="py", role="obj", uri="page_url")]),
+        Inventory([InventoryItem(name="object_path", domain="py", role="obj", uri="page_url#object_path")]),
+        Inventory([InventoryItem(name="object_path", domain="py", role="obj", uri="page_url#other_anchor")]),
+        Inventory([InventoryItem(name="o", domain="py", role="obj", uri="u#o", dispname="first line\nsecond line")]),
+    ],
+)
+def test_mkdocstrings_roundtrip_inventory_file(our_inv: Inventory) -> None:
+    """Save some inventory files, then load them in again."""
+    buffer = BytesIO(our_inv.format_sphinx())
+    round_tripped = Inventory.parse_sphinx(buffer)
+
+    assert our_inv.keys() == round_tripped.keys()
+    for key, value in our_inv.items():
+        round_tripped_item = round_tripped[key]
+        assert round_tripped_item.name == value.name
+        assert round_tripped_item.domain == value.domain
+        assert round_tripped_item.role == value.role
+        assert round_tripped_item.uri == value.uri
+        assert round_tripped_item.priority == value.priority
+        assert round_tripped_item.dispname == value.dispname.splitlines()[0]
